diff lisp/calendar/calendar.el @ 60922:4e6ed80c0af2

* calendar/calendar.el: Replace `legal' with `valid'.
author Werner LEMBERG <wl@gnu.org>
date Fri, 25 Mar 2005 09:53:47 +0000
parents 3a754b1548d3
children 7f7db25577d9
line wrap: on
line diff
--- a/lisp/calendar/calendar.el	Fri Mar 25 09:51:55 2005 +0000
+++ b/lisp/calendar/calendar.el	Fri Mar 25 09:53:47 2005 +0000
@@ -2884,20 +2884,20 @@
   (redraw-calendar))
 
 (defun calendar-date-is-visible-p (date)
-  "Return t if DATE is legal and is visible in the calendar window."
+  "Return t if DATE is valid and is visible in the calendar window."
   (let ((gap (calendar-interval
               displayed-month displayed-year
               (extract-calendar-month date) (extract-calendar-year date))))
     (and (calendar-date-is-legal-p date) (> 2 gap) (< -2 gap))))
 
 (defun calendar-date-is-legal-p (date)
-  "Return t if DATE is a legal date."
+  "Return t if DATE is a valid date."
   (let ((month (extract-calendar-month date))
         (day (extract-calendar-day date))
         (year (extract-calendar-year date)))
     (and (<= 1 month) (<= month 12)
          (<= 1 day) (<= day (calendar-last-day-of-month month year))
          ;; BC dates left as non-legal, to suppress errors from
          ;; complex holiday algorithms not suitable for years BC.
          ;; Note there are side effects on calendar navigation.
          (<= 1 year))))
@@ -2884,20 +2884,20 @@
     (and (<= 1 month) (<= month 12)
          (<= 1 day) (<= day (calendar-last-day-of-month month year))
-         ;; BC dates left as non-legal, to suppress errors from
+         ;; BC dates left as non-valid, to suppress errors from
          ;; complex holiday algorithms not suitable for years BC.
          ;; Note there are side effects on calendar navigation.